/*
	DLL para carga de ficheros en segundo plano.
	
	BACKGROUND_LOAD_XXX (int pointer id, string filename);
	XXX se sustituye por FNT, FPG, MAP, PAL, PCX, PNG, SONG o WAV.
	El primer parmetro es un puntero al entero donde se almacenar el codigo identificador del fichero cargado.
	El segundo parmetro es una cadena con el nombre del archivo que queremos cargar.
	Para saber si el fichero se ha cargado deberemos comprobar si el id es distinto de 0.
	
	MaQNaZiLLeR
*/
#include <stdlib.h>
#include <fxdll.h>
#include "SDL.h"
#include "SDL_thread.h"

typedef struct{
	char *file;
	int *id, (*fn)();
}_d;

int load(void *d){
	_d *t=(_d*)d;
	*(t->id)=(*t->fn)(t->file);
	free(t);
	return 0;
}

_d *prep(int *params){
	_d *t=(_d*)malloc(sizeof(_d));
	t->file=(char *)string_get(params[1]);
	t->id=(int*)params[0];
	return t;
}

// FNT
static int background_load_fnt(INSTANCE * my, int * params)
{
	_d *t=prep(params);
	t->fn=gr_font_load;
	SDL_CreateThread(load,(void *)t);
	return 0 ;
}


// FPG
static int background_load_fpg(INSTANCE * my, int * params)
{
	_d *t=prep(params);
	t->fn=gr_load_fpg;
	SDL_CreateThread(load,(void *)t);
	return 0 ;
}


// MAP
static int background_load_map(INSTANCE * my, int * params)
{
	_d *t=prep(params);
	t->fn=gr_load_map;
	SDL_CreateThread(load,(void *)t);
	return 0 ;
}


// PAL
static int background_load_pal(INSTANCE * my, int * params)
{
	_d *t=prep(params);
	t->fn=gr_load_pal;
	SDL_CreateThread(load,(void *)t);
	return 0 ;
}


// PCX
static int background_load_pcx(INSTANCE * my, int * params)
{
	_d *t=prep(params);
	t->fn=gr_load_pcx;
	SDL_CreateThread(load,(void *)t);
	return 0 ;
}


// PNG
static int background_load_png(INSTANCE * my, int * params)
{
	_d *t=prep(params);
	t->fn=gr_load_png;
	SDL_CreateThread(load,(void *)t);
	return 0 ;
}


// SONG
static int background_load_song(INSTANCE * my, int * params)
{
	_d *t=prep(params);
	t->fn=load_song;
	SDL_CreateThread(load,(void *)t);
	return 0 ;
}


// WAV
static int background_load_wav(INSTANCE * my, int * params)
{
	_d *t=prep(params);
	t->fn=load_wav;
	SDL_CreateThread(load,(void *)t);
	return 0 ;
}


FENIX_MainDLL RegisterFunctions (COMMON_PARAMS)
{
    FENIX_DLLImport

	FENIX_export ("BACKGROUND_LOAD_FNT" , "PS", TYPE_DWORD, background_load_fnt);
	FENIX_export ("BACKGROUND_LOAD_FPG" , "PS", TYPE_DWORD, background_load_fpg);
	FENIX_export ("BACKGROUND_LOAD_MAP" , "PS", TYPE_DWORD, background_load_map);
	FENIX_export ("BACKGROUND_LOAD_PAL" , "PS", TYPE_DWORD, background_load_pal);
	FENIX_export ("BACKGROUND_LOAD_PCX" , "PS", TYPE_DWORD, background_load_pcx);
	FENIX_export ("BACKGROUND_LOAD_PNG" , "PS", TYPE_DWORD, background_load_png);
	FENIX_export ("BACKGROUND_LOAD_SONG", "PS", TYPE_DWORD, background_load_song);
	FENIX_export ("BACKGROUND_LOAD_WAV" , "PS", TYPE_DWORD, background_load_wav);
}
